==> ejc-assistrmat-api-3.0.0-20220415.115443-76-sources.jar: com/ejianc/business/assist/store/vo/AllotInDetailVO.java <==
package com.ejianc.business.assist.store.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;


/**
 * 调拨入库子表
 * 
 * @author generator
 * 
 */
public class AllotInDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    

    private Long allocatId; // 主表id
    private Long materialCategoryId; // 物资分类id
    private String materialCategoryName; // 物资分类名称
    private Long materialId; // 物资id
    private String materialName; // 物资名称
    private String materialSpec; // 规格型号
    private Long materialUnitId; // 物资计量单位id
    private String materialUnit; // 物资计量单位
    private BigDecimal surplusNum; // 剩余可用数量
    private BigDecimal allocatNum; // 调拨数量
    private BigDecimal allocatPrice; // 调拨单价
    private BigDecimal allocatTaxPrice; // 调拨单价（有税）
    private BigDecimal allocatTaxRate; // 调拨税率
    private BigDecimal allocatMny; // 调拨金额
    private BigDecimal allocatTaxMny; // 调拨单价（有税）
    private BigDecimal allocatTax; // 调拨税额
    private BigDecimal inStoreAveragePrice; // 入库均价
    private BigDecimal inStoreTax; // 入库税额
    private BigDecimal inStoreMny; // 入库金额
    private BigDecimal inStoreTaxMny; // 入库金额（有税）
    private String memo; // 备注
    private BigDecimal inStoreTaxRate;//入库税率


    public Long getAllocatId() {
        return allocatId;
    }

    public void setAllocatId(Long allocatId) {
        this.allocatId = allocatId;
    }

    public Long getMaterialCategoryId() {
        return materialCategoryId;
    }

    public void setMaterialCategoryId(Long materialCategoryId) {
        this.materialCategoryId = materialCategoryId;
    }
    public String getMaterialCategoryName() {
        return materialCategoryName;
    }

    public void setMaterialCategoryName(String materialCategoryName) {
        this.materialCategoryName = materialCategoryName;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getMaterialSpec() {
        return materialSpec;
    }

    public void setMaterialSpec(String materialSpec) {
        this.materialSpec = materialSpec;
    }
    public Long getMaterialUnitId() {
        return materialUnitId;
    }

    public void setMaterialUnitId(Long materialUnitId) {
        this.materialUnitId = materialUnitId;
    }
    public String getMaterialUnit() {
        return materialUnit;
    }

    public void setMaterialUnit(String materialUnit) {
        this.materialUnit = materialUnit;
    }
    public BigDecimal getSurplusNum() {
        return surplusNum;
    }

    public void setSurplusNum(BigDecimal surplusNum) {
        this.surplusNum = surplusNum;
    }
    public BigDecimal getAllocatNum() {
        return allocatNum;
    }

    public void setAllocatNum(BigDecimal allocatNum) {
        this.allocatNum = allocatNum;
    }
    public BigDecimal getAllocatPrice() {
        return allocatPrice;
    }

    public void setAllocatPrice(BigDecimal allocatPrice) {
        this.allocatPrice = allocatPrice;
    }
    public BigDecimal getAllocatTaxPrice() {
        return allocatTaxPrice;
    }

    public void setAllocatTaxPrice(BigDecimal allocatTaxPrice) {
        this.allocatTaxPrice = allocatTaxPrice;
    }

    public BigDecimal getAllocatTaxRate() {
        return allocatTaxRate;
    }

    public void setAllocatTaxRate(BigDecimal allocatTaxRate) {
        this.allocatTaxRate = allocatTaxRate;
    }

    public BigDecimal getAllocatMny() {
        return allocatMny;
    }

    public void setAllocatMny(BigDecimal allocatMny) {
        this.allocatMny = allocatMny;
    }
    public BigDecimal getAllocatTaxMny() {
        return allocatTaxMny;
    }

    public void setAllocatTaxMny(BigDecimal allocatTaxMny) {
        this.allocatTaxMny = allocatTaxMny;
    }
    public BigDecimal getAllocatTax() {
        return allocatTax;
    }

    public void setAllocatTax(BigDecimal allocatTax) {
        this.allocatTax = allocatTax;
    }
    public BigDecimal getInStoreAveragePrice() {
        return inStoreAveragePrice;
    }

    public void setInStoreAveragePrice(BigDecimal inStoreAveragePrice) {
        this.inStoreAveragePrice = inStoreAveragePrice;
    }
    public BigDecimal getInStoreTax() {
        return inStoreTax;
    }

    public void setInStoreTax(BigDecimal inStoreTax) {
        this.inStoreTax = inStoreTax;
    }
    public BigDecimal getInStoreMny() {
        return inStoreMny;
    }

    public void setInStoreMny(BigDecimal inStoreMny) {
        this.inStoreMny = inStoreMny;
    }

    public BigDecimal getInStoreTaxMny() {
        return inStoreTaxMny;
    }

    public void setInStoreTaxMny(BigDecimal inStoreTaxMny) {
        this.inStoreTaxMny = inStoreTaxMny;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public BigDecimal getInStoreTaxRate() {
        return inStoreTaxRate;
    }

    public void setInStoreTaxRate(BigDecimal inStoreTaxRate) {
        this.inStoreTaxRate = inStoreTaxRate;
    }
}

==> ejc-assistrmat-api-3.0.0-20221101.020733-293-sources.jar: com/ejianc/business/assist/store/vo/AllotInDetailVO.java <==
package com.ejianc.business.assist.store.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;


/**
 * 调拨入库子表
 * 
 * @author generator
 * 
 */
public class AllotInDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    

    private Long allocatId; // 主表id
    private Long materialCategoryId; // 物资分类id
    private String materialCategoryName; // 物资分类名称
    private Long materialId; // 物资id
    private String materialName; // 物资名称
    private String materialSpec; // 规格型号
    private Long materialUnitId; // 物资计量单位id
    private String materialUnit; // 物资计量单位
    private BigDecimal surplusNum; // 剩余可用数量
    private BigDecimal allocatNum; // 调拨数量
    private BigDecimal allocatPrice; // 调拨单价
    private BigDecimal allocatTaxPrice; // 调拨单价（有税）
    private BigDecimal allocatTaxRate; // 调拨税率
    private BigDecimal allocatMny; // 调拨金额
    private BigDecimal allocatTaxMny; // 调拨单价（有税）
    private BigDecimal allocatTax; // 调拨税额
    private BigDecimal inStoreAveragePrice; // 入库均价
    private BigDecimal inStoreTax; // 入库税额
    private BigDecimal inStoreMny; // 入库金额
    private BigDecimal inStoreTaxMny; // 入库金额（有税）
    private String memo; // 备注
    private BigDecimal inStoreTaxRate;//入库税率

    private BigDecimal netWorthTaxMny; // 材料净值(含税)
    private BigDecimal netWorthMny; // 材料净值(无税)
    private BigDecimal originalValueTaxPrice; // 原值单价(含税)
    private BigDecimal originalValuePrice; // 原值单价(无税)
    private BigDecimal originalValueTaxMny; // 材料原值(含税)
    private BigDecimal originalValueMny; // 材料原值(无税)
    private BigDecimal onHandNum; // 在场数量
    private BigDecimal allocatBlanceMny; // 调拨差额(无税)
    private BigDecimal allocatBlanceTaxMny; // 调拨差额
    private BigDecimal netWorthTax; // 材料税额
    private BigDecimal netWorthTaxRate; // 材料税率

    private String materialCode; // 物资编码

    public BigDecimal getNetWorthTaxMny() {
        return netWorthTaxMny;
    }

    public void setNetWorthTaxMny(BigDecimal netWorthTaxMny) {
        this.netWorthTaxMny = netWorthTaxMny;
    }

    public BigDecimal getNetWorthMny() {
        return netWorthMny;
    }

    public void setNetWorthMny(BigDecimal netWorthMny) {
        this.netWorthMny = netWorthMny;
    }

    public BigDecimal getOriginalValueTaxPrice() {
        return originalValueTaxPrice;
    }

    public void setOriginalValueTaxPrice(BigDecimal originalValueTaxPrice) {
        this.originalValueTaxPrice = originalValueTaxPrice;
    }

    public BigDecimal getOriginalValuePrice() {
        return originalValuePrice;
    }

    public void setOriginalValuePrice(BigDecimal originalValuePrice) {
        this.originalValuePrice = originalValuePrice;
    }

    public BigDecimal getOriginalValueTaxMny() {
        return originalValueTaxMny;
    }

    public void setOriginalValueTaxMny(BigDecimal originalValueTaxMny) {
        this.originalValueTaxMny = originalValueTaxMny;
    }

    public BigDecimal getOriginalValueMny() {
        return originalValueMny;
    }

    public void setOriginalValueMny(BigDecimal originalValueMny) {
        this.originalValueMny = originalValueMny;
    }

    public BigDecimal getOnHandNum() {
        return onHandNum;
    }

    public void setOnHandNum(BigDecimal onHandNum) {
        this.onHandNum = onHandNum;
    }

    public BigDecimal getAllocatBlanceMny() {
        return allocatBlanceMny;
    }

    public void setAllocatBlanceMny(BigDecimal allocatBlanceMny) {
        this.allocatBlanceMny = allocatBlanceMny;
    }

    public BigDecimal getAllocatBlanceTaxMny() {
        return allocatBlanceTaxMny;
    }

    public void setAllocatBlanceTaxMny(BigDecimal allocatBlanceTaxMny) {
        this.allocatBlanceTaxMny = allocatBlanceTaxMny;
    }

    public BigDecimal getNetWorthTax() {
        return netWorthTax;
    }

    public void setNetWorthTax(BigDecimal netWorthTax) {
        this.netWorthTax = netWorthTax;
    }

    public BigDecimal getNetWorthTaxRate() {
        return netWorthTaxRate;
    }

    public void setNetWorthTaxRate(BigDecimal netWorthTaxRate) {
        this.netWorthTaxRate = netWorthTaxRate;
    }

    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }

    public Long getAllocatId() {
        return allocatId;
    }

    public void setAllocatId(Long allocatId) {
        this.allocatId = allocatId;
    }

    public Long getMaterialCategoryId() {
        return materialCategoryId;
    }

    public void setMaterialCategoryId(Long materialCategoryId) {
        this.materialCategoryId = materialCategoryId;
    }
    public String getMaterialCategoryName() {
        return materialCategoryName;
    }

    public void setMaterialCategoryName(String materialCategoryName) {
        this.materialCategoryName = materialCategoryName;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getMaterialSpec() {
        return materialSpec;
    }

    public void setMaterialSpec(String materialSpec) {
        this.materialSpec = materialSpec;
    }
    public Long getMaterialUnitId() {
        return materialUnitId;
    }

    public void setMaterialUnitId(Long materialUnitId) {
        this.materialUnitId = materialUnitId;
    }
    public String getMaterialUnit() {
        return materialUnit;
    }

    public void setMaterialUnit(String materialUnit) {
        this.materialUnit = materialUnit;
    }
    public BigDecimal getSurplusNum() {
        return surplusNum;
    }

    public void setSurplusNum(BigDecimal surplusNum) {
        this.surplusNum = surplusNum;
    }
    public BigDecimal getAllocatNum() {
        return allocatNum;
    }

    public void setAllocatNum(BigDecimal allocatNum) {
        this.allocatNum = allocatNum;
    }
    public BigDecimal getAllocatPrice() {
        return allocatPrice;
    }

    public void setAllocatPrice(BigDecimal allocatPrice) {
        this.allocatPrice = allocatPrice;
    }
    public BigDecimal getAllocatTaxPrice() {
        return allocatTaxPrice;
    }

    public void setAllocatTaxPrice(BigDecimal allocatTaxPrice) {
        this.allocatTaxPrice = allocatTaxPrice;
    }

    public BigDecimal getAllocatTaxRate() {
        return allocatTaxRate;
    }

    public void setAllocatTaxRate(BigDecimal allocatTaxRate) {
        this.allocatTaxRate = allocatTaxRate;
    }

    public BigDecimal getAllocatMny() {
        return allocatMny;
    }

    public void setAllocatMny(BigDecimal allocatMny) {
        this.allocatMny = allocatMny;
    }
    public BigDecimal getAllocatTaxMny() {
        return allocatTaxMny;
    }

    public void setAllocatTaxMny(BigDecimal allocatTaxMny) {
        this.allocatTaxMny = allocatTaxMny;
    }
    public BigDecimal getAllocatTax() {
        return allocatTax;
    }

    public void setAllocatTax(BigDecimal allocatTax) {
        this.allocatTax = allocatTax;
    }
    public BigDecimal getInStoreAveragePrice() {
        return inStoreAveragePrice;
    }

    public void setInStoreAveragePrice(BigDecimal inStoreAveragePrice) {
        this.inStoreAveragePrice = inStoreAveragePrice;
    }
    public BigDecimal getInStoreTax() {
        return inStoreTax;
    }

    public void setInStoreTax(BigDecimal inStoreTax) {
        this.inStoreTax = inStoreTax;
    }
    public BigDecimal getInStoreMny() {
        return inStoreMny;
    }

    public void setInStoreMny(BigDecimal inStoreMny) {
        this.inStoreMny = inStoreMny;
    }

    public BigDecimal getInStoreTaxMny() {
        return inStoreTaxMny;
    }

    public void setInStoreTaxMny(BigDecimal inStoreTaxMny) {
        this.inStoreTaxMny = inStoreTaxMny;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public BigDecimal getInStoreTaxRate() {
        return inStoreTaxRate;
    }

    public void setInStoreTaxRate(BigDecimal inStoreTaxRate) {
        this.inStoreTaxRate = inStoreTaxRate;
    }
}
